@@ -311,11 +311,14 @@ def file_replace(abs_path, each_file_code_list):
             prelineno=start_row, end_row
         else:
             prelineno = min(start_row,prelineno[0]), max(end_row,prelineno[1])
+
     with open(abs_path) as f:
         lines=f.readlines()
         # print("lines: ",lines)
         # return None
         pre_lineno=None
+        if not group_new_sorted_code_list:
+            return "".join(lines)
         for ind_group,each_group_code in  enumerate(group_new_sorted_code_list):
             # print("1. each_group_code: ",each_group_code,len(each_group_code))
             bias=each_group_code[0][0]-1
@@ -480,7 +483,7 @@ def file_replace(abs_path, each_file_code_list):
                     pre_lineno=max(start_row,pre_lineno[0]), max(end_row,pre_lineno[1])
                 else:
                     pre_lineno=start_row, end_row
-                if ind_each_code==len(each_group_code)-1:
+            if ind_group==len(each_group_code)-1:
                     new_content.extend(lines[pre_lineno[1]:])
 
 
@@ -538,22 +541,27 @@ def main(args):
         code_frag = util.load_file_path(file_path=filepath)
 
         format_code_list,dict_code_pair=get_refactoring(idiom, code_frag,filepath)
+
         if not flag_outputdir_mergeallcodepair:
             if os.path.exists(output_dir):
                 shutil.rmtree(output_dir)
             for ind_save, each_code_pair in enumerate(format_code_list):
+                print("come here")
                 new_content = file_replace(filepath, [each_code_pair])
-
+                print("new_content: ",new_content)
                 util.save_file_path("".join([output_dir, "/", file_name[:-3], '_', str(ind_save), '.py']),
                                     new_content)
 
 
+
                 # util.save_file_path()
 
         else:
             new_content = file_replace(filepath, format_code_list)
+            print("new_content: ", new_content)
             if os.path.exists(output_dir):
                 shutil.rmtree(output_dir)
+            print("new_content: ", new_content)
             util.save_file_path("".join([output_dir, "/",file_name] ), new_content)
 
             # util.save_file_path()
@@ -578,6 +586,8 @@ if __name__ == '__main__':
     #
     parser.add_argument('--idiom', type=str,
                         help='idiom', default="All")
+    # parser.add_argument('--idiom', type=str,
+    #                     help='idiom', default="List Comprehension")
     parser.add_argument('--outputdir', type=str,
                         help='outputdir', default="./RefactoringIdiomsOutputdir/")
     # parser.add_argument('--outputdir', type=str,
@@ -585,7 +595,7 @@ if __name__ == '__main__':
     #
     # parser.add_argument('--flag_merge_allcodepair', type=str,
     #                     help='flag_merge_allcodepair', default=1)
-    parser.add_argument('--flag_merge_allcodepair', type=str,
+    parser.add_argument('--flag_merge_allcodepair', type=int,
                         help='flag_merge_allcodepair', default=0)
     parser.add_argument('--output_codepair', type=str,
                         help='output_codepair', default="result.json")
